@@ -10,9 +10,9 @@ def main() -> None:
     content = sys.argv[3]
     cipher = AESCipher(key)
     if command == "e":
-        print(cipher.encrypt(content))
+        p(cipher.encrypt(content))
     elif command == "d":
-        print(cipher.decrypt(content))
+        p(cipher.decrypt(content))
     else:
         exit(1)
     exit(0)
